==> boofcv-geo-0.34-sources.jar: boofcv/struct/geo/PointIndex2D_F64.java <==
/*
 * Copyright (c) 2011-2019, Peter Abeles. All Rights Reserved.
 *
 * This file is part of BoofCV (http://boofcv.org).
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package boofcv.struct.geo;

import georegression.struct.point.Point2D_F64;

/**
 * A 2D point with an index associated with it
 *
 * @author Peter Abeles
 */
public class PointIndex2D_F64 extends Point2D_F64 {
	public int index;

	public PointIndex2D_F64(double x, double y, int index) {
		super(x, y);
		this.index = index;
	}

	public PointIndex2D_F64(double x, double y) {
		super(x, y);
	}

	public PointIndex2D_F64() {
	}

	public PointIndex2D_F64( Point2D_F64 p , int index ) {
		this.x = p.x;
		this.y = p.y;
		this.index = index;
	}

	public void set( PointIndex2D_F64 src ) {
		this.x = src.x;
		this.y = src.y;
		this.index = src.index;
	}

	public int getIndex() {
		return index;
	}

	public void setIndex(int index) {
		this.index = index;
	}

	public PointIndex2D_F64 copy() {
		return new PointIndex2D_F64(x,y,index);
	}
}

==> boofcv-geo-0.36.1-sources.jar: boofcv/struct/geo/PointIndex2D_F64.java <==
/*
 * Copyright (c) 2011-2020, Peter Abeles. All Rights Reserved.
 *
 * This file is part of BoofCV (http://boofcv.org).
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package boofcv.struct.geo;

import georegression.struct.point.Point2D_F64;

/**
 * A 2D point with an index associated with it
 *
 * @author Peter Abeles
 */
public class PointIndex2D_F64 extends Point2D_F64 {
	public int index;

	public PointIndex2D_F64(double x, double y, int index) {
		super(x, y);
		this.index = index;
	}

	public PointIndex2D_F64(double x, double y) {
		super(x, y);
	}

	public PointIndex2D_F64() {
	}

	public PointIndex2D_F64( Point2D_F64 p , int index ) {
		set(p,index);
	}

	public void set( Point2D_F64 p , int index ) {
		this.x = p.x;
		this.y = p.y;
		this.index = index;
	}

	public void set( double x , double y , int index ) {
		this.x = x;
		this.y = y;
		this.index = index;
	}

	public void set( PointIndex2D_F64 src ) {
		this.x = src.x;
		this.y = src.y;
		this.index = src.index;
	}

	public int getIndex() {
		return index;
	}

	public void setIndex(int index) {
		this.index = index;
	}

	public PointIndex2D_F64 copy() {
		return new PointIndex2D_F64(x,y,index);
	}
}
